/******************** (C) COPYRIGHT 2025 Sinowealth *****************************
 * File Name          : SH30F9810_gcc.ld
 * Author             : Auto-generated
 * Version            : V1.3.1
 * Date               : 2025-03-19
 * Abstract           : Set heap size, stack size and stack location according
 *                      to application requirements.
 * Description        : The file is distributed "as is," without any warranty
 *                      of any kind.
 ********************************************************************************
 * 
 * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY ON SINOWEALTH
 * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
 * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
 * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
 * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
 * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
 * CONNECTION WITH THEIR PRODUCTS.
 *
 * <h2><center>&copy; COPYRIGHT 2025 Sinowealth</center></h2>
 *
 ********************************************************************************
*/

/* Entry Point */
ENTRY(Reset_Handler)

/* Highest address of the user mode stack */
_estack = ORIGIN(ram) + LENGTH(ram);    /* end of RAM */
/*
  Generate a link error if heap and stack don't fit into RAM.
  These numbers affect the USED size of RAM
*/
_Min_Heap_Size  = 0x100;   /* required amount of heap: 256 bytes */
_Min_Stack_Size = 0x200;   /* required amount of stack: 512 bytes */

/* Internal Memory Map*/
MEMORY
{
    rom (rx)   : ORIGIN = 0x00000000, LENGTH = 0x00020000
    ram (rwx)  : ORIGIN = 0x20000000, LENGTH = 0x00004000
    C_OPT (rx) : ORIGIN = 0x0FFFA000, LENGTH = 0x00000200
}

SECTIONS
{
    /* The startup code goes first into FLASH */
    .isr_vector :
    {
        . = ALIGN(4);
        KEEP(*(.isr_vector)) /* Startup code */
        . = ALIGN(4);
    } >rom
    
    /* The program code and other data goes into FLASH */
    .text :
    {
        . = ALIGN(4);
        *(.text)           /* .text sections (code)  */
        *(.text*)          /* .text* sections (code) */
        *(.rodata)         /* .rodata sections (constants, strings, etc.) */
        *(.rodata*)        /* .rodata* sections (constants, strings, etc.) */
        *(.glue_7)         /* glue arm to thumb code */
        *(.glue_7t)        /* glue thumb to arm code */

        KEEP(*(.init))
        KEEP(*(.fini))
        
        /* .ctors */
        *crtbegin.o(.ctors)
        *crtbegin?.o(.ctors)
        *(EXCLUDE_FILE(*crtend?.o *crtend.o) .ctors)
        *(SORT(.ctors.*))
        *(.ctors)
        
        /* .dtors */
        *crtbegin.o(.dtors)
        *crtbegin?.o(.dtors)
        *(EXCLUDE_FILE(*crtend?.o *crtend.o) .dtors)
        *(SORT(.dtors.*))
        *(.dtors)

        KEEP(*(.eh_frame*))
        . = ALIGN(4);
    } > rom 

    .ARM.extab : {*(.ARM.extab* .gnu.linkonce.armextab.*)} > rom 
    
    __exidx_start = .;
    .ARM.exidx :
    {
        *(.ARM.exidx* .gnu.linkonce.armexidx.*)
    } > rom 
    __exidx_end = .;
    /* Location counter can end up 2byte aligned with narrow Thumb code but
       __etext is assumed by startup code to be the LMA of a section in RAM
       which must be 4byte aligned */
    . = ALIGN(4);
    __etext = .;
    /* _sidata is used in coide startup code */
    _sidata = __etext;
    .data : AT (_sidata)
    {
        __data_start__ = .; /* create a global symbol at data start */
        
        /* _sdata is used in coide startup code */
        _sdata = __data_start__;
        
        *(vtable)
        *(.data*)           /* .data* sections */
        
        . = ALIGN(4);
        /* preinit data */
        PROVIDE_HIDDEN (__preinit_array_start = .);
        KEEP(*(.preinit_array))
        PROVIDE_HIDDEN (__preinit_array_end = .);
        
        . = ALIGN(4);
        /* init data */
        PROVIDE_HIDDEN (__init_array_start = .);
        KEEP(*(SORT(.init_array.*)))
        KEEP(*(.init_array))
        PROVIDE_HIDDEN (__init_array_end = .);
        
        . = ALIGN(4);
        /* finit data */
        PROVIDE_HIDDEN (__fini_array_start = .);
        KEEP(*(SORT(.fini_array.*)))
        KEEP(*(.fini_array))
        PROVIDE_HIDDEN (__fini_array_end = .);
        
        KEEP(*(.jcr*))
        . = ALIGN(4);
        /* All data end */
        __data_end__ = .;
        
        /* _edata is used in coide startup code */
        _edata = __data_end__;
    } > ram 
    
    /* Uninitialized data section */
    . = ALIGN(4);
    .bss :
    {
        /* This is used by the startup in order to initialize the .bss secion */
        _sbss = .;         /* define a global symbol at bss start */
        __bss_start__ = _sbss;
        *(.bss)
        *(.bss*)
        *(COMMON)

        . = ALIGN(4);
        _ebss = .;         /* define a global symbol at bss end */
        __bss_end__ = _ebss;
    } >ram

    /* User_heap_stack section, used to check that there is enough RAM left */
    ._user_heap_stack :
    {
        . = ALIGN(8);
        PROVIDE ( end = . );
        PROVIDE ( _end = . );
        . = . + _Min_Heap_Size;
        . = . + _Min_Stack_Size;
        . = ALIGN(8);
    } >ram

    /* The customer option code goes into FLASH(customer area) */
    .customer_option :
    {
        . = ALIGN(4);
        KEEP(*(.customer_option)) /* customer option */
        . = ALIGN(4);
    } > C_OPT
}

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
