/******************** (C) COPYRIGHT 2025 Sinowealth *****************************
 * File Name          : startup_sh30f9xx_sb0_gcc.S
 * Author             : SINOWEALTH Application Team
 * Version            : V1.1
 * Date               : 2025-03-05
 * Description        : SH30F9 SB0 devices vector table for GNU toolchain.
 *                      This module performs:
 *                      - Set the initial SP
 *                      - Set the initial PC == Reset_Handler,
 *                      - Set the vector table entries with the exceptions ISR 
 *                        address.
 *                      - Branches to main in the C library (which eventually
 *                        calls main()).
 *                      After Reset the Cortex-M0+ processor is in Thread mode,
 *                      priority is Privileged, and the Stack is set to Main.
 ********************************************************************************
 * 
 * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY ON SINOWEALTH
 * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
 * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
 * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
 * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
 * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
 * CONNECTION WITH THEIR PRODUCTS.
 *
 * <h2><center>&copy; COPYRIGHT 2025 Sinowealth</center></h2>
 *
 ********************************************************************************
 */

    .syntax unified
    .cpu cortex-m0plus
    .fpu softvfp
    .thumb
    
    .global g_pfnVectors
    .global Reset_Handler

/**
 * @brief  This is the code that gets called when the processor first
 *         starts execution following a reset event. Only the absolutely
 *         necessary set is performed, after which the application
 *         supplied main() routine is called.
 * @param  None
 * @retval None
 */

    .section  .text.Reset_Handler,"ax",%progbits
    .type Reset_Handler, %function
Reset_Handler:

    /* Call the low level init function.*/
    bl  SystemInit

    movs r1, #0
    b    LoopCopyDataInit

CopyDataInit:
    ldr  r3, =_sidata
    ldr  r3, [r3, r1]
    str  r3, [r0, r1]
    adds r1, r1, #4

LoopCopyDataInit:
    ldr  r0, =_sdata
    ldr  r3, =_edata
    adds r2, r0, r1
    cmp  r2, r3
    bcc  CopyDataInit
    ldr  r2, =_sbss
    b    LoopFillZerobss

    ;/* Zero fill the bss segment. */  

FillZerobss:
    movs r3, #0
    str  r3, [r2]
    adds r2,r2,#4

LoopFillZerobss:
    ldr r3, =_ebss
    cmp r2, r3
    bcc FillZerobss

    /* Call static constructors */
    /* bl  __libc_init_array*/

    /* Call the application's entry point.*/
    bl  main
    bx  lr    
    b  .  

    .size  Reset_Handler, .-Reset_Handler

/**
 * @brief  This is the code that gets called when the processor receives an
 *         unexpected interrupt.  This simply enters an infinite loop, preserving
 *         the system state for examination by a debugger.
 *
 * @param  None
 * @retval None
 */
    .section  .text.System_Handler,"ax",%progbits
    .type System_Handler, %function
System_Handler:
    b  .
    .size  System_Handler, .-System_Handler

    .section  .text.Default_Handler,"ax",%progbits
    .type Default_Handler, %function
Default_Handler:
    b  .   
    .size  Default_Handler, .-Default_Handler

    .section  .text.User_Handler,"ax",%progbits
    .type User_Handler, %function
User_Handler:
    b  .
    .size  User_Handler, .-User_Handler

    .weak SystemInit
    .thumb_set SystemInit, SystemInit_Default
    .section  .text.SystemInit,"ax",%progbits   
    .type SystemInit_Default, %function
SystemInit_Default:
    bx lr
    .size SystemInit_Default, .-SystemInit_Default


/******************************************************************************
*
* The minimal vector table for a Cortex-M0+.  Note that the proper constructs
* must be placed on this to ensure that it ends up at physical address
* 0x0000.0000.
*
******************************************************************************/
    .section .isr_vector,"a",%progbits
    .type g_pfnVectors, %object
    .size g_pfnVectors, .-g_pfnVectors


g_pfnVectors:
    .word    _estack              ;/* -16 (000H) Top of Stack                                  */
    .word    Reset_Handler        ;/* -15 (004H) Reset Handler                                 */
    .word    NMI_Handler          ;/* -14 (008H) Non Maskable Interrupt                        */
    .word    HardFault_Handler    ;/* -13 (00CH) Hard Fault Interrupt                          */
    .word    Default_Handler      ;/* -12 (010H) Reserved                                      */
    .word    Default_Handler      ;/* -11 (014H) Reserved                                      */
    .word    Default_Handler      ;/* -10 (018H) Reserved                                      */
    .word    Default_Handler      ;/*  -9 (01CH) Reserved                                      */
    .word    Default_Handler      ;/*  -8 (020H) Reserved                                      */
    .word    Default_Handler      ;/*  -7 (024H) Reserved                                      */
    .word    Default_Handler      ;/*  -6 (028H) Reserved                                      */
    .word    SVC_Handler          ;/*  -5 (02CH) SV Call Interrupt                             */
    .word    Default_Handler      ;/*  -4 (030H) Reserved                                      */
    .word    Default_Handler      ;/*  -3 (034H) Reserved                                      */
    .word    PendSV_Handler       ;/*  -2 (038H) Pend SV Interrupt                             */
    .word    SysTick_Handler      ;/*  -1 (03CH) System Tick Interrupt                         */
    .word    WWDT_Handler         ;/*   0 (040H) WWDT Interrupt                                */
    .word    BOD_Handler          ;/*   1 (044H) BOD Interrupt                                 */
    .word    RCC_Handler          ;/*   2 (048H) RCC Interrupt                                 */
    .word    EXTI0_Handler        ;/*   3 (04CH) EXTI0 Interrupt                               */
    .word    EXTI1_Handler        ;/*   4 (050H) EXTI1 Interrupt                               */
    .word    EXTI2_Handler        ;/*   5 (054H) EXTI2 Interrupt                               */
    .word    EXTI3_Handler        ;/*   6 (058H) EXTI3 Interrupt                               */
    .word    ADC_Handler          ;/*   7 (05CH) ADC Interrupt                                 */
    .word    TWI0_Handler         ;/*   8 (060H) TWI0 Interrupt                                */
    .word    TWI1_Handler         ;/*   9 (064H) TWI1 Interrupt                                */
    .word    PCA0_Handler         ;/*  10 (068H) PCA0 Interrupt                                */
    .word    PCA1_Handler         ;/*  11 (06CH) PCA1 Interrupt                                */
    .word    PCA2_Handler         ;/*  12 (070H) PCA2 Interrupt                                */
    .word    PCA3_Handler         ;/*  13 (074H) PCA3 Interrupt                                */
    .word    EXTI9_4_Handler      ;/*  14 (078H) EXTI9_4 Interrupt                             */
    .word    UART0_Handler        ;/*  15 (07CH) UART0 Interrupt                               */
    .word    SPI0_Handler         ;/*  16 (080H) SPI0 Interrupt                                */
    .word    SPI1_Handler         ;/*  17 (084H) SPI1 Interrupt                                */
    .word    UART1_Handler        ;/*  18 (088H) UART1 Interrupt                               */
    .word    UART2_Handler        ;/*  19 (08CH) UART2 Interrupt                               */
    .word    UART3_Handler        ;/*  20 (090H) UART3 Interrupt                               */
    .word    EXTI15_10_Handler    ;/*  21 (094H) EXTI15_10 Interrupt                           */
    .word    UART4_Handler        ;/*  22 (098H) UART4 Interrupt                               */
    .word    UART5_Handler        ;/*  23 (09CH) UART5 Interrupt                               */
    .word    PWM0_Handler         ;/*  24 (0A0H) PWM0 Interrupt                                */
    .word    PWM1_Handler         ;/*  25 (0A4H) PWM1 Interrupt                                */
    .word    PWM2_Handler         ;/*  26 (0A8H) PWM2 Interrupt                                */
    .word    PWM3_Handler         ;/*  27 (0ACH) PWM3 Interrupt                                */
    .word    TIM0_Handler         ;/*  28 (0B0H) TIM0 Interrupt                                */
    .word    TIM1_FIFO0_Handler   ;/*  29 (0B4H) TIM1_FIFO0 Interrupt                          */
    .word    TIM2_FIFO1_Handler   ;/*  30 (0B8H) TIM2_FIFO1 Interrupt                          */
    .word    TIM3_FIFO2_Handler   ;/*  31 (0BCH) TIM3_FIFO2 Interrupt                          */

/*******************************************************************************
*
* Provide weak aliases for each Exception handler to the Default_Handler.
* As they are weak aliases, any function with the same name will override
* this definition.
*
*******************************************************************************/

    .weak      NMI_Handler
    .thumb_set NMI_Handler,         System_Handler

    .weak      HardFault_Handler
    .thumb_set HardFault_Handler,   System_Handler

    .weak      MemManage_Handler
    .thumb_set MemManage_Handler,   System_Handler

    .weak      BusFault_Handler
    .thumb_set BusFault_Handler,    System_Handler

    .weak      UsageFault_Handler
    .thumb_set UsageFault_Handler,  System_Handler

    .weak      SVC_Handler
    .thumb_set SVC_Handler,         System_Handler

    .weak      DebugMon_Handler
    .thumb_set DebugMon_Handler,    System_Handler

    .weak      PendSV_Handler
    .thumb_set PendSV_Handler,      System_Handler

    .weak      SysTick_Handler
    .thumb_set SysTick_Handler,     System_Handler

    .weak      WWDT_Handler        
    .thumb_set WWDT_Handler,        User_Handler
    .weak      BOD_Handler         
    .thumb_set BOD_Handler,         User_Handler
    .weak      RCC_Handler         
    .thumb_set RCC_Handler,         User_Handler
    .weak      EXTI0_Handler       
    .thumb_set EXTI0_Handler,       User_Handler
    .weak      EXTI1_Handler       
    .thumb_set EXTI1_Handler,       User_Handler
    .weak      EXTI2_Handler       
    .thumb_set EXTI2_Handler,       User_Handler
    .weak      EXTI3_Handler       
    .thumb_set EXTI3_Handler,       User_Handler
    .weak      ADC_Handler         
    .thumb_set ADC_Handler,         User_Handler
    .weak      TWI0_Handler        
    .thumb_set TWI0_Handler,        User_Handler
    .weak      TWI1_Handler        
    .thumb_set TWI1_Handler,        User_Handler
    .weak      PCA0_Handler        
    .thumb_set PCA0_Handler,        User_Handler
    .weak      PCA1_Handler        
    .thumb_set PCA1_Handler,        User_Handler
    .weak      PCA2_Handler        
    .thumb_set PCA2_Handler,        User_Handler
    .weak      PCA3_Handler        
    .thumb_set PCA3_Handler,        User_Handler
    .weak      EXTI9_4_Handler     
    .thumb_set EXTI9_4_Handler,     User_Handler
    .weak      UART0_Handler       
    .thumb_set UART0_Handler,       User_Handler
    .weak      SPI0_Handler        
    .thumb_set SPI0_Handler,        User_Handler
    .weak      SPI1_Handler        
    .thumb_set SPI1_Handler,        User_Handler
    .weak      UART1_Handler       
    .thumb_set UART1_Handler,       User_Handler
    .weak      UART2_Handler       
    .thumb_set UART2_Handler,       User_Handler
    .weak      UART3_Handler       
    .thumb_set UART3_Handler,       User_Handler
    .weak      EXTI15_10_Handler   
    .thumb_set EXTI15_10_Handler,   User_Handler
    .weak      UART4_Handler       
    .thumb_set UART4_Handler,       User_Handler
    .weak      UART5_Handler       
    .thumb_set UART5_Handler,       User_Handler
    .weak      PWM0_Handler        
    .thumb_set PWM0_Handler,        User_Handler
    .weak      PWM1_Handler        
    .thumb_set PWM1_Handler,        User_Handler
    .weak      PWM2_Handler        
    .thumb_set PWM2_Handler,        User_Handler
    .weak      PWM3_Handler        
    .thumb_set PWM3_Handler,        User_Handler
    .weak      TIM0_Handler        
    .thumb_set TIM0_Handler,        User_Handler
    .weak      TIM1_FIFO0_Handler  
    .thumb_set TIM1_FIFO0_Handler,  User_Handler
    .weak      TIM2_FIFO1_Handler  
    .thumb_set TIM2_FIFO1_Handler,  User_Handler
    .weak      TIM3_FIFO2_Handler  
    .thumb_set TIM3_FIFO2_Handler,  User_Handler


/*********************** (C) COPYRIGHT SINOWEALTH *** END OF FILE*****/
