/**
 * @file      sh30f9xx_sb0_customeroption.c
 * @brief     When using J-link or CMSIS-DAP simulation tools, 
              please add this file configuration file
 * @author    sinowealth software group ()
 * @date      2025-01-16
 * @version   V1.0
 * @copyright Copyright (c) 1994 - 2025 SINOWEALTH Electronic Ltd.
 * 
 * @attention
 * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY ON SINOWEALTH'S
 * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
 * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
 * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
 * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
 * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
 * CONNECTION WITH THEIR PRODUCTS.
 * @par Change log:
 * <table>
 * <tr><th>Date        <th>Version  <th>Author    <th>Description
 * <tr><td>2025-01-16  <td>1.0      <td>bruce     <td>Create initial version
 * </table>
 */

/*
//-------- <<< Use Configuration Wizard in Context Menu >>> ------------------
*/

// <o.0..31> Customer ID
#define CUST_ID      0x00000000


// <o.0..31> Serial Number
#define CUST_SN      0x00000000


/*--------------------- Customer Option ----------------------------------*/
//
// <h> Customer Option
//  <o.6> FLASH_SELECT(Only valid when FLASH_DIVDE = 1)
//                <0=> PC pointer addresses from Main Memory(Default)
//                <1=> PC pointer addresses from Backup Memory
//  <o.7> FLASH_DIVDE
//                <0=> Flash is not divided into blocks(Default)
//                <1=> Flash is divided into two blocks,Main Memory and Backup Memory

#define OPT_BYTE0          0x00

//  <o.5> OP_LVREN
//                <0=> Disable LVR function(Default)
//                <1=> Enable LVR function
//  <o.6..7> OP_LVRLE
//                <0=> 4.1V LVR Level(Default)
//                <1=> 3.7V LVR Level
//                <2=> 3.1V LVR Level

#define OPT_BYTE1          0x00
#define OPT_BYTE2          0x00
#define OPT_BYTE3          0x00
#define OPT_BYTE4          0x00
#define OPT_BYTE5          0x00
#define OPT_BYTE6          0x00
#define OPT_BYTE7          0x00

//</h>

#if defined( __CC_ARM )    // ARM Compiler 5
    const unsigned long CUSTOMER_OPTION[128] __attribute__((at(0x0FFFA000))) = {
#elif defined( __clang__ ) // ARM Compiler 6
    const unsigned long CUSTOMER_OPTION[128] __attribute__((section(".ARM.__at_0x0FFFA000"))) = {
#elif defined( __IAR_SYSTEMS_ICC__ ) //IAR
    __root const unsigned long CUSTOMER_OPTION[128] @ 0x0FFFA000 = {
#else  //GNUC
    const unsigned long CUSTOMER_OPTION[128] __attribute__((section(".customer_option"))) = {
#endif
    CUST_ID,0,((OPT_BYTE3<<24)|(OPT_BYTE2<<16)|(OPT_BYTE1<<8)|(OPT_BYTE0)), //000H
    ((OPT_BYTE7<<24)|(OPT_BYTE6<<16)|(OPT_BYTE5<<8)|(OPT_BYTE4)),
    0,0,0,0,                                            //010H
    0,0,0,0,                                            //020H
    0,0,0,CUST_SN,                                      //030H
    0,0,0,0,                                            //040H
    0,0,0,0,                                            //050H
    0,0,0,0,                                            //060H
    0,0,0,0,                                            //070H
    0,0,0,0,                                            //080H
    0,0,0,0,                                            //090H
    0,0,0,0,                                            //0A0H
    0,0,0,0,                                            //0B0H
    0,0,0,0,                                            //0C0H
    0,0,0,0,                                            //0D0H
    0,0,0,0,                                            //0E0H
    0,0,0,0,                                            //0F0H
    0,0,0,0,                                            //100H
    0,0,0,0,                                            //110H
    0,0,0,0,                                            //120H
    0,0,0,0,                                            //130H
    0,0,0,0,                                            //140H
    0,0,0,0,                                            //150H
    0,0,0,0,                                            //160H
    0,0,0,0,                                            //170H
    0,0,0,0,                                            //180H
    0,0,0,0,                                            //190H
    0,0,0,0,                                            //1A0H
    0,0,0,0,                                            //1B0H
    0,0,0,0,                                            //1C0H
    0,0,0,0,                                            //1D0H
    0,0,0,0,                                            //1E0H
    0,0,0,0,                                            //1F0H
};    

//-------------------- <<< end of configuration section >>> --------------------
