/**
  ******************************************************************************
  * @file    sh30f9xx_sb0_retarget.c
  * @author  sinowealth
  * @version V1.0.1
  * @date    2025-04-25
  * @brief   this file provides printf retargetting functions
  *
  * @verbatim
  *
  *=============================================================================
  * How to use this driver
  *=============================================================================
  * 1. if PRINTF function is required, defined _MODULE_DBG_PRINTF in preprocessor symbols,
  *    then select output mode is ITM or UART and modify some parameters according
  *    configuration wizard in sh30f9xx_sb0_retarget.h
  * 2. add this file into the project
  * 3. if using RTE environment or UTE environment or other, please must add sh30f9xx_sb0_gpio.c,
       sh30f9xx_sb0_uart.c, sh30f9xx_sb0_rcc.c driver module into the project
  * 4. use printf to output the debugging information
  * 5. if disable this feature(undefined _MODULE_DBG_PRINTF), no codes added into the project
  * 6. if a redefined assertion is used in the driver library, defined DEFAULT_ASSERT_ENABLE in preprocessor symbols.
  * 7. If using the AC6 compiler, it is recommended to use Microlib (Option ->Target: use Microlib). 
  *    Otherwise, please add retarget_io. c to the project
  * @endverbatim
  *
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY ON SINOWEALTH'S
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS.
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2025 Sinowealth</center></h2>
  *
  ******************************************************************************
  */

/* Includes ------------------------------------------------------------------*/
#include <stdio.h>
#include "sh30f9xx_sb0_retarget.h"

/** @defgroup Retarget_Group Retarget
 * @{
 */

/** @defgroup Retarget_Group_Pub_Funcs  Public Functions
 * @{
 */

#ifdef _MODULE_DBG_PRINTF

#    if (defined(__clang__) && (__ARMCC_VERSION >= 6000000) && !defined(__MICROLIB)) || defined(__GNUC__)
__asm(".global __use_no_semihosting\n\t");

void _sys_exit(int x)
{
    (void)x;
}
void _ttywrch(int ch)
{
    (void)ch;
}
void _ttywrch_retarget(int ch)
{
    (void)ch;
}

#    elif defined(__CC_ARM) && (__ARMCC_VERSION < 6000000) && !defined(__MICROLIB)

struct __FILE
{
    int handle;
};
FILE __stdout;
FILE __stdin;

#    elif defined(__ICCARM__)
struct __FILE
{
    int handle;
};
typedef struct __FILE FILE;
FILE __stdout;
FILE __stdin;
#    endif

static void Uart_Init_Config(UART_TypeDef *uart, uint32_t u32SR);

#    if (1 == UART_SELECT)
static void Set_CrystalPort_IO(void)
{
    uint32_t temp            = 0;
    RCC->RCCLOCK             = 0x33CC;  // Unlock RCC Config Register
    RCC->AHBENR.BIT.SYSCFGEN = 1;       // Enable SYSCFG Module
    temp                     = SYSCFG->SAFR.V32;
    temp &= (~SYSCFG_SAFR_OSCCFG_Msk);
    SYSCFG->SAFR.V32 =
        (0x5AA5 << 16 | temp);  // Unlock SYSCFG SAFR register and set XTAL1 and XTAL2 pin to GPIO function
    RCC->RCCLOCK = 0;
}
#    endif

#    if (0 == UART_SELECT) || (1 == UART_SELECT)
static void Set_DebugPort_IO(void)
{
    uint32_t temp            = 0;
    RCC->RCCLOCK             = 0x33CC;  // Unlock RCC Config Register
    RCC->AHBENR.BIT.SYSCFGEN = 1;       // Enable SYSCFG Module
    temp                     = SYSCFG->SAFR.V32;
    temp &= (~SYSCFG_SAFR_SWJCFG_Msk);
    SYSCFG->SAFR.V32 =
        (0x5AA5 << 16 | temp);  // Unlock SYSCFG SAFR register and set SWDIO and SWCLK pin to GPIO function
    RCC->RCCLOCK = 0;
}
#    endif

static void UART_PinReamp(void)
{
    RCC_AHBPeriphClockOnOff(RCC_AHB_GPIO, SH_ON);
    /***********Configure UART pins*****************/
#    if (0 == UART_SELECT)
    switch (UART0_PIN & 0xF0)
    {
        case 0x00: GPIOA->AFRL.BIT.AFR2 = 2; break;  // TXD PA2
        case 0x10: GPIOA->AFRL.BIT.AFR3 = 2; break;  // TXD PA3
        case 0x20: GPIOC->AFRL.BIT.AFR3 = 2; break;  // TXD PC3
        case 0x30: GPIOC->AFRL.BIT.AFR4 = 2; break;  // TXD PC4
        case 0x40: GPIOC->AFRL.BIT.AFR5 = 2; break;  // TXD PC5
        case 0x50: GPIOD->AFRL.BIT.AFR0 = 2; break;  // TXD PD0
        case 0x60: GPIOD->AFRL.BIT.AFR1 = 2; break;  // TXD PD1
        default: break;
    }
    switch (UART0_PIN & 0x0F)
    {
        case 0x00:
            Set_DebugPort_IO();
            GPIOA->AFRL.BIT.AFR4 = 3;
            break;                                   // RXD PA4
        case 0x01: GPIOC->AFRL.BIT.AFR3 = 3; break;  // RXD PC3
        case 0x02: GPIOC->AFRL.BIT.AFR4 = 3; break;  // RXD PC4
        case 0x03: GPIOC->AFRL.BIT.AFR5 = 3; break;  // RXD PC5
        case 0x04: GPIOD->AFRL.BIT.AFR0 = 3; break;  // RXD PD0
        case 0x05: GPIOD->AFRL.BIT.AFR1 = 3; break;  // RXD PD1
        default: break;
    }
#    endif  // endif (0 == UART_SELECT)
#    if (1 == UART_SELECT)
    switch (UART1_PIN & 0xF0)
    {
        case 0x00:
            Set_DebugPort_IO();
            GPIOA->AFRL.BIT.AFR5 = 2;
            break;                                   // TXD PA5
        case 0x10: GPIOA->AFRH.BIT.AFR9 = 2; break;  // TXD PA9
        case 0x20:
            Set_CrystalPort_IO();
            GPIOA->AFRH.BIT.AFR10 = 2;
            break;                                    // TXD PA10
        case 0x30:
            Set_CrystalPort_IO();
            GPIOA->AFRH.BIT.AFR11 = 2;
            break;                                    // TXD PA11
        case 0x40: GPIOB->AFRL.BIT.AFR4  = 2; break;  // TXD PB4
        case 0x50: GPIOC->AFRH.BIT.AFR8  = 2; break;  // TXD PC8
        case 0x60: GPIOC->AFRH.BIT.AFR9  = 2; break;  // TXD PC9
        case 0x70: GPIOD->AFRL.BIT.AFR2  = 2; break;  // TXD PD2
        case 0x80: GPIOD->AFRL.BIT.AFR3  = 2; break;  // TXD PD3
        case 0x90: GPIOD->AFRH.BIT.AFR13 = 2; break;  // TXD PD13
        case 0xA0: GPIOD->AFRH.BIT.AFR14 = 2; break;  // TXD PD14
        default: break;
    }
    switch (UART1_PIN & 0x0F)
    {
        case 0x00:
            Set_CrystalPort_IO();
            GPIOA->AFRH.BIT.AFR10 = 3;
            break;                                    // RXD PA10
        case 0x01:
            Set_CrystalPort_IO();
            GPIOA->AFRH.BIT.AFR11 = 3;
            break;                                    // RXD PA11
        case 0x02: GPIOB->AFRL.BIT.AFR5  = 3; break;  // RXD PB5
        case 0x03: GPIOC->AFRH.BIT.AFR8  = 3; break;  // RXD PC8
        case 0x04: GPIOC->AFRH.BIT.AFR9  = 3; break;  // RXD PC9
        case 0x05: GPIOD->AFRL.BIT.AFR2  = 3; break;  // RXD PD2
        case 0x06: GPIOD->AFRL.BIT.AFR3  = 3; break;  // RXD PD3
        case 0x07: GPIOD->AFRH.BIT.AFR13 = 3; break;  // RXD PD13
        case 0x08: GPIOD->AFRH.BIT.AFR14 = 3; break;  // RXD PD14
        default: break;
    }
#    endif  // endif (1 == UART_SELECT)

#    if (2 == UART_SELECT)
    switch (UART2_PIN & 0xF0)
    {
        case 0x00: GPIOA->AFRL.BIT.AFR6  = 2; break;  // TXD PA6
        case 0x10: GPIOB->AFRL.BIT.AFR6  = 2; break;  // TXD PB6
        case 0x20: GPIOC->AFRH.BIT.AFR10 = 2; break;  // TXD PC10
        case 0x30: GPIOC->AFRH.BIT.AFR11 = 2; break;  // TXD PC11
        case 0x40: GPIOD->AFRL.BIT.AFR7  = 2; break;  // TXD PD7
        case 0x50: GPIOD->AFRH.BIT.AFR8  = 2; break;  // TXD PD8
        case 0x60: GPIOD->AFRH.BIT.AFR9  = 2; break;  // TXD PD9
        case 0x70: GPIOD->AFRH.BIT.AFR10 = 2; break;  // TXD PD10
        default: break;
    }
    switch (UART2_PIN & 0x0F)
    {
        case 0x00: GPIOA->AFRL.BIT.AFR7  = 3; break;  // RXD PA7
        case 0x01: GPIOB->AFRL.BIT.AFR7  = 3; break;  // RXD PB7
        case 0x02: GPIOC->AFRH.BIT.AFR10 = 3; break;  // RXD PC10
        case 0x03: GPIOC->AFRH.BIT.AFR11 = 3; break;  // RXD PC11
        case 0x04: GPIOD->AFRL.BIT.AFR7  = 3; break;  // RXD PD7
        case 0x05: GPIOD->AFRH.BIT.AFR8  = 3; break;  // RXD PD8
        case 0x06: GPIOD->AFRH.BIT.AFR9  = 3; break;  // RXD PD9
        default: break;
    }
#    endif  // endif (2 == UART_SELECT)

#    if (3 == UART_SELECT)
    //-------UART3 Port-------
    switch (UART3_PIN & 0xF0)
    {
        case 0x00: GPIOA->AFRL.BIT.AFR0  = 2; break;  // TXD PA0
        case 0x10: GPIOA->AFRH.BIT.AFR15 = 2; break;  // TXD PA15
        case 0x20: GPIOB->AFRL.BIT.AFR0  = 2; break;  // TXD PB0
        case 0x30: GPIOB->AFRL.BIT.AFR2  = 2; break;  // TXD PB2
        case 0x40: GPIOC->AFRL.BIT.AFR6  = 2; break;  // TXD PC6
        case 0x50: GPIOC->AFRL.BIT.AFR7  = 2; break;  // TXD PC7
        default: break;
    }
    switch (UART3_PIN & 0x0F)
    {
        case 0x00: GPIOA->AFRL.BIT.AFR0  = 3; break;  // RXD PA0
        case 0x01: GPIOA->AFRL.BIT.AFR1  = 3; break;  // RXD PA1
        case 0x02: GPIOA->AFRH.BIT.AFR15 = 3; break;  // RXD PA15
        case 0x03: GPIOB->AFRL.BIT.AFR0  = 3; break;  // RXD PB0
        case 0x04: GPIOB->AFRL.BIT.AFR1  = 3; break;  // RXD PB1
        case 0x05: GPIOB->AFRL.BIT.AFR3  = 3; break;  // RXD PB3
        case 0x06: GPIOC->AFRL.BIT.AFR6  = 3; break;  // RXD PC6
        case 0x07: GPIOC->AFRL.BIT.AFR7  = 3; break;  // RXD PC7
        case 0x08: GPIOD->AFRH.BIT.AFR10 = 3; break;  // RXD PD10
        default: break;
    }
#    endif  // endif (3 == UART_SELECT)

#    if (4 == UART_SELECT)
    //-------UART4 Port-------
    switch (UART4_PIN & 0xF0)
    {
        case 0x00: GPIOA->AFRH.BIT.AFR8  = 2; break;  // TXD PA8
        case 0x10: GPIOB->AFRH.BIT.AFR14 = 2; break;  // TXD PB14
        case 0x20: GPIOB->AFRH.BIT.AFR15 = 2; break;  // TXD PB15
        case 0x30: GPIOC->AFRH.BIT.AFR12 = 2; break;  // TXD PC12
        case 0x40: GPIOC->AFRH.BIT.AFR13 = 2; break;  // TXD PC13
        default: break;
    }
    switch (UART4_PIN & 0x0F)
    {
        case 0x00: GPIOA->AFRH.BIT.AFR9  = 3; break;  // RXD PA9
        case 0x01: GPIOB->AFRH.BIT.AFR14 = 3; break;  // RXD PB14
        case 0x02: GPIOB->AFRH.BIT.AFR15 = 3; break;  // RXD PB15
        case 0x03: GPIOC->AFRH.BIT.AFR12 = 3; break;  // RXD PC12
        case 0x04: GPIOC->AFRH.BIT.AFR13 = 3; break;  // RXD PC13
        default: break;
    }
#    endif  // endif (4 == UART_SELECT)

#    if (5 == UART_SELECT)
    //-------UART5 Port-------
    switch (UART5_PIN & 0xF0)
    {
        case 0x00: GPIOA->AFRH.BIT.AFR12 = 2; break;  // TXD PA12
        case 0x10: GPIOB->AFRH.BIT.AFR9  = 2; break;  // TXD PB9
        case 0x20: GPIOB->AFRH.BIT.AFR12 = 2; break;  // TXD PB12
        case 0x30: GPIOB->AFRH.BIT.AFR13 = 2; break;  // TXD PB13
        case 0x40: GPIOC->AFRL.BIT.AFR0  = 2; break;  // TXD PC0
        case 0x50: GPIOC->AFRH.BIT.AFR14 = 2; break;  // TXD PC14
        case 0x60: GPIOD->AFRL.BIT.AFR4  = 2; break;  // TXD PD4
        case 0x70: GPIOD->AFRL.BIT.AFR5  = 2; break;  // TXD PD5
        case 0x80: GPIOD->AFRL.BIT.AFR6  = 2; break;  // TXD PD6
        default: break;
    }
    switch (UART5_PIN & 0x0F)
    {
        case 0x00: GPIOA->AFRH.BIT.AFR12 = 3; break;  // RXD PA12
        case 0x01: GPIOB->AFRH.BIT.AFR9  = 3; break;  // RXD PB9
        case 0x02: GPIOB->AFRH.BIT.AFR12 = 3; break;  // RXD PB12
        case 0x03: GPIOB->AFRH.BIT.AFR13 = 3; break;  // RXD PB13
        case 0x04: GPIOC->AFRL.BIT.AFR1  = 3; break;  // RXD PC1
        case 0x05: GPIOC->AFRH.BIT.AFR15 = 3; break;  // RXD PC15
        case 0x06: GPIOD->AFRL.BIT.AFR4  = 3; break;  // RXD PD4
        case 0x07: GPIOD->AFRL.BIT.AFR5  = 3; break;  // RXD PD5
        case 0x08: GPIOD->AFRL.BIT.AFR6  = 3; break;  // RXD PD6
        default: break;
    }
#    endif  // endif (5 == UART_SELECT)
}
/**
 * @brief  retarget initial function.
 * @note   1. initial the retarget device   2. can be selected as ITM or UART
 * @retval None
 */
void RetargetInit(void)
{
    Uart_Init_Config(UARTx, UART_BAUD_DEFAULT);
}

/**
 * @brief  uart send.
 * @param  uart: uart corresponding channel.
 * @param  ch: send data.
 * @note   None
 * @retval uint8_t: data to transmit
 */
static uint8_t uart_send(UART_TypeDef *uart, uint8_t ch)
{
    while (uart->FR.BIT.TI == 0)
    {
        __NOP();
    }
    uart->TDR.BIT.TDR = ch;
    return ch;
}

/**
 * @brief  uart read.
 * @param  uart: uart corresponding channel.
 * @note   None
 * @retval uint8_t: return read data
 */
static uint8_t uart_read(UART_TypeDef *uart)
{
    uint8_t ch;
    while (uart->FR.BIT.RI == 0)
    {
        HWDT->CLR = 0xAAAA;
    }
    ch = uart->RDR.BIT.RDR;
    return ch;
}

/**
 * @brief  uart init.
 * @param  uart: uart corresponding channel.
 * @param  u32SR: uart baud rate.
 * @note   None
 * @retval None
 */
void Uart_Init_Config(UART_TypeDef *uart, uint32_t u32SR)
{
    UART_InitTypeDef UART_InitStructure;

    UART_ClockOnOff(uart, SH_ON);

    UART_PinReamp();

    UART_InitStructure.UART_Mode     = UART_Mode_1;
    UART_InitStructure.UART_BaudRate = u32SR;
    UART_InitStructure.UART_StopBits = UART_StopBits_1;
    UART_InitStructure.UART_Parity   = UART_SoftWare_Custom;
    UART_InitStructure.UART_Enable   = UART_Enable_Tx_Rx;
    UART_Init(uart, &UART_InitStructure);
}

#    if defined(__ICCARM__) || defined(__CC_ARM) || defined(__clang__)
/**
 * @brief  output character function.
 * @param  ch: output character
 * @param  f: file handle.
 * @note   None
 * @retval int: outputted character
 */
int fputc(int ch, FILE *f)
{
    (void)f;
    if(ch == '\n') 
    {
        uart_send(UARTx, '\r');
    }
    return (int)uart_send(UARTx, (uint8_t)ch);
}

/**
 * @brief  input retarget.
 * @param  f: file handle.
 * @note   None
 * @retval int: character which read
 */
int fgetc(FILE *f)
{
    (void)f;
    int ch = uart_read(UARTx);
    uart_send(UARTx, ch);
    if (ch == '\r')
        uart_send(UARTx, '\n');
    return (ch);
}

#    elif defined(__GNUC__)

/**
 * @brief  provide the function for GCC printf.
 * @param  fd: file pointer no used
 * @param  pBuffer: data buffer
 * @param  size: data buffer size
 * @note   None
 * @retval int: outputted data size
 */
int _write(int fd, const char *pBuffer, int size)
{
    (void)fd;
    for(int i=0; i<size; i++)
    {
        if(pBuffer[i] == '\n') 
        {
            uart_send(UARTx, '\r');
        }
        uart_send(UARTx, pBuffer[i]);
    }

    return size;
}

/**
 * @brief  provide the function for GCC printf.
 * @param  fd: file pointer no used
 * @param  pBuffer: data buffer
 * @param  size: data buffer size
 * @note   None
 * @retval int: readed data size
 */
int _read(int fd, char *pBuffer, int size)
{
    (void)fd;
    int cnt = 0;
    while (cnt < size)
    {
        *pBuffer = uart_read(UARTx);
        uart_send(UARTx, *pBuffer);
        if (*pBuffer == '\r')
        {
            *pBuffer = '\n';
            uart_send(UARTx, '\n');

            cnt++;
            break;
        }
        pBuffer++;
        cnt++;
    }

    return cnt;
}
#    endif

/*! flush printf buffer to output device */
#    if defined(__ICCARM__)

/**
 * @brief  replace the function putchar for IAR printf.
 * @param  ch: data to output device
 * @note   None
 * @retval int: data to output device
 */
int putchar(int ch)
{
    if (ch == '\n')
    {
        uart_send(UARTx, '\r');
    }
    uart_send(UARTx, (uint8_t)ch);
    return ch;
}

/**
 * @brief  replace the function getchar for IAR scanf.
 * @note   None
 * @retval int: data readed from input device
 */
int getchar(void)
{
    int ch = uart_read(UARTx);
    uart_send(UARTx, (uint8_t)ch);
    if (ch == '\r')
        uart_send(UARTx, '\n');
    return (ch);
}

/**
 * @brief  for replace the function in getchar.o.
 * @param  a: this is the character to be pushed in.
 *            the character is passed with its corresponding int value
 * @note   None
 * @retval int:returns the character
 */
int __ungetchar(int ch)
{
    return ch;
}

/**
 * @brief  for replace the function in getchar.o.
 * @note   None
 * @retval int:returns the character
 */
int _UngetChar(void)
{
    return -1;
}

#    endif /*__ICCARM__*/

/**
 * @brief  flush printf buffer to output device.
 * @note   None
 * @retval None
 */
void flush_printfbuffer(void)
{
#    if defined(__clang__) || defined(__GNUC__)
    fflush(stdout);
#    else

#    endif
}
#endif /* _MODULE_DBG_PRINTF */

#ifdef DEFAULT_ASSERT_ENABLE

/**
 * @brief  Provide an assertion failure function.
 * @param  file: file pointer
 * @param  line: The line Number
 * @note   None
 * @retval None
 */
void assert_failed(uint8_t *file, uint32_t line)
{
#    ifdef _MODULE_DBG_PRINTF
    printf("Assert failed: %s line %d\n", file, (int)line);
#    else
    (void)file;
    (void)line;
    __BKPT(0);
#    endif
    while (1);
}
#endif /* DEFAULT_ASSERT_ENABLE*/

/**
 * @}
 */

/**
 * @}
 */

/******************* (C) COPYRIGHT 2025 Sinowealth *****END OF FILE************/
