/**
 * @file      sh30f9xx_sb0_retarget.h
 * @brief     
 * @author    sinowealth software group ()
 * @date      2024-06-20
 * @version   V1.0
 * @copyright Copyright (c) 1994 - 2024 SINOWEALTH Electronic Ltd.
 * 
 * @attention
 * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY ON SINOWEALTH'S
 * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
 * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
 * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
 * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
 * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
 * CONNECTION WITH THEIR PRODUCTS.
 * @par Change log:
 * <table>
 * <tr><th>Date        <th>Version  <th>Author    <th>Description
 * <tr><td>2024-06-20  <td>1.0      <td>bruce     <td>Create initial version
 * </table>
 */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH30F9XX_SB0_RETARGET_H
#define __SH30F9XX_SB0_RETARGET_H

/* Includes ------------------------------------------------------------------*/
#include "sh30f9xx_sb0_libcfg.h"


#ifdef __cplusplus
 extern "C" {
#endif

/*****************************************************************************/
//-------- <<< Use Configuration Wizard in Context Menu >>> -----------------
/*****************************************************************************/

//<o> UART Baud Rate Setting
#define  UART_BAUD_DEFAULT   9600

//<o> UART SELECT
//   <0=> UART0
//   <1=> UART1
//   <2=> UART2
//   <3=> UART3
//   <4=> UART4
//   <5=> UART5
#define  UART_SELECT    2

#if (UART_SELECT == 0)
    #define UARTx  UART0
#elif (UART_SELECT == 1)
    #define UARTx  UART1
#elif (UART_SELECT == 2)
    #define UARTx  UART2
#elif (UART_SELECT == 3)
    #define UARTx  UART3
#elif (UART_SELECT == 4)
    #define UARTx  UART4
#elif (UART_SELECT == 5)
    #define UARTx  UART5
#endif

//    <h>UART0 Pin Select
//        <o0.4..7>TXD0 <0=>PA2 <1=>PA3 <2=>PC3 <3=>PC4 <4=>PC5 <5=>PD0 <6=>PD1
//        <o0.0..3>RXD0 <0=>PA4 <1=>PC3 <2=>PC4 <3=>PC5 <4=>PD0 <5=>PD1
//    </h>
//    <h>UART1 Pin Select
//        <o1.4..7>TXD1 <0=>PA5 <1=>PA9 <2=>PA10 <3=>PA11 <4=>PB4 <5=>PC8 <6=>PC9<7=>PD2<8=>PD3<9=>PD13<9=>PD14
//        <o1.0..3>RXD1 <0=>PA10 <1=>PA11 <2=>PB5 <3=>PC8 <4=>PC9 <5=>PD2 <6=>PD3 <7=>PD13 <8=>PD14
//    </h>
//    <h>UART2 Pin Select
//        <o2.4..7>TXD2 <0=>PA6 <1=>PB6 <2=>PC10 <3=>PC11 <4=>PD7 <5=>PD8 <6=>PD9 <7=>PD10
//        <o2.0..2>RXD2 <0=>PA7 <1=>PB7 <2=>PC10 <3=>PC11 <4=>PD7 <5=>PD8 <6=>PD9
//    </h>
//    <h>UART3 Pin Select
//        <o3.4..7>TXD3 <0=>PA0 <1=>PA15 <2=>PB0 <3=>PB2 <4=>PC6 <5=>PC7
//        <o3.0..3>RXD3 <0=>PA0 <1=>PA1 <2=>PA15 <3=>PB0 <4=>PB1 <5=>PB3 <6=>PC6 <7=>PC7 <8=>PD10
//    </h>
//    <h>UART4 Pin Select
//        <o4.4..7>TXD4 <0=>PA8 <1=>PB14 <2=>PB15 <3=>PC12 <4=>PC13
//        <o4.0..3>RXD4 <0=>PA9 <1=>PB14 <2=>PB15 <3=>PC12 <4=>PC13
//    </h>
//    <h>UART5 Pin Select
//        <o5.4..7>TXD5 <0=>PA12 <1=>PB9 <2=>PB12 <3=>PB13 <4=>PC0 <5=>PC14 <6=>PD4 <7=>PD5 <8=>PD6
//        <o5.0..3>RXD5 <0=>PA12 <1=>PB9 <2=>PB12 <3=>PB13 <4=>PC1 <5=>PC15 <6=>PD4 <7=>PD5 <8=>PD6
//    </h>
#define UART0_PIN              0x00    //UART0 Pin Select
#define UART1_PIN              0x00    //UART1 Pin Select
#define UART2_PIN              0x11    //UART2 Pin Select
#define UART3_PIN              0x38    //UART3 Pin Select
#define UART4_PIN              0x40    //UART4 Pin Select
#define UART5_PIN              0x87    //UART5 Pin Select

/*****************************************************************************/
//-------- <<< end of configuration section >>> -----------------------------
/*****************************************************************************/
/** @addtogroup Retarget_Group
  * @{
  */

/* Exported types ------------------------------------------------------------*/
/* Exported constants --------------------------------------------------------*/

/* Exported macro ------------------------------------------------------------*/


/** @addtogroup Retarget_Group_Pub_Funcs
  * @{
  */
/*! Retarget Init function */
void RetargetInit(void);

/*! flush printf buffer to output device */
void flush_printfbuffer(void);

/**
  * @}
  */


/**
  * @}
  */


#ifdef __cplusplus
}
#endif

#endif /*__SH30F9XX_SB0_RETARGET_H */



/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
